@@ -23,7 +23,8 @@ int ap,
 struct type_230 *t230)
     {
     struct data_corel *datum;
-    complex work_array[4 * MAXLAG], value;
+    complex value;
+    static complex work_array[4 * MAXLAG];
     double theta;
     int i, j, lag, nl;
     int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L, 1:R
