@@ -165,22 +165,22 @@ void generate_text (struct scan_struct *root,
     else if (param.pol < 16)
         {
         polstrx[0] = '\0';
-        if (param.pol & POLMASK_LL)
+        if (param.pol & POLMASK_LL && pass->pprods_present[0])
             {
             strcat (polstrx, "+LL");
             polars |= LREF | LREM;
             }
-        if (param.pol & POLMASK_RR)
+        if (param.pol & POLMASK_RR && pass->pprods_present[1])
             {
             strcat (polstrx, "+RR");
             polars |= RREF | RREM;
             }
-        if (param.pol & POLMASK_LR)
+        if (param.pol & POLMASK_LR && pass->pprods_present[2])
             {
             strcat (polstrx, "+LR");
             polars |= LREF | RREM;
             }
-        if (param.pol & POLMASK_RL)
+        if (param.pol & POLMASK_RL && pass->pprods_present[3])
             {
             strcat (polstrx, "+RL");
             polars |= RREF | LREM;
@@ -192,8 +192,8 @@ void generate_text (struct scan_struct *root,
         sprintf (polstr, "Ixy");
         polars |= LREF | LREM | RREF | RREM;
         }
-                                    // substitute linear pol symbols if apropos
-        modify_pol (pass, polstr);
+                                        // substitute linear pol symbols if apropos
+    modify_pol (pass, polstr);
     sprintf (buf, "%.8s - %.8s, fgroup %c, pol %s", fringe.t202->ref_name,
                     fringe.t202->rem_name, pass->pass_data[0].fgroup, polstr);
     pscat ("/Helvetica-Bold findfont 140 scalefont setfont\n");
@@ -854,8 +854,8 @@ void generate_text (struct scan_struct *root,
     psleft (0.23, ypos, "Inc. frq. avg.");
     sprintf (buf, "%.3f", fringe.t208->inc_chan_ampl);
     psleft (0.35, ypos, buf);
-    sprintf (buf, "Data rate(Mb/s): %d", numsb * eff_npols * srate 
-            * sqrt ((double)(param.bits_sample[0] * param.bits_sample[1])));
+    sprintf (buf, "Data rate(Mb/s): %d", (int)(numsb * eff_npols * srate 
+            * sqrt ((double)(param.bits_sample[0] * param.bits_sample[1])) + 0.5));
     psleft (0.5, ypos, buf);
     sprintf (buf, "nlags: %d", param.nlags);
     psleft (0.65, ypos, buf);
