@@ -68,8 +68,14 @@ struct c_block *cb_ptr;
     for (i=0; i<6; i++)
         cb_ptr -> adhoc_poly[i] = NULLFLOAT;
 
-    for (i=0; i<8; i++)
+    for (i=0; i<MAX_SAMP; i++)
+        {
         cb_ptr -> psamplers[i] = NULL;
+        cb_ptr -> sampler_delay[i][0].ref = NULLFLOAT;
+        cb_ptr -> sampler_delay[i][1].ref = NULLFLOAT;
+        cb_ptr -> sampler_delay[i][0].rem = NULLFLOAT;
+        cb_ptr -> sampler_delay[i][1].rem = NULLFLOAT;
+        }
 
     for (i=0; i<2; i++)
         {
