@@ -14,9 +14,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "print_page.h"
+//#include "print_page.h"
 
-#define BOUNDS_ERROR		FALSE
+//#define BOUNDS_ERROR		FALSE
+#define BOUNDS_ERROR		0
 
 void 
 put_char_at ( matrix, x, y, c )
