@@ -113,7 +113,7 @@ rotate_pcal(struct type_pass *pass)
                 if (cabs (rrpcal[0]) + cabs (rrpcal[1]) == 0.0) 
                     theta = 0.0;
                                         // save resulting phasor in time-freq array
-                cor_data->pc_phasor[ip] = cexp (I * (theta - zeta - eta[ip]));
+                cor_data->pc_phasor[ip] = cexp (I * (theta - zeta + eta[ip]));
                 }
             }
         }
